# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaselineLogEntry(Model):
    """NOTE: This child object is subject to change depending on what we want to
    log.

    :param meter_id: ID of the meter
    :type meter_id: int
    :param status: Status of the meter's baseline processing
    :type status: str
    :param message: Error or warning message from baseline processing
     Will be blank if no errors or warnings
    :type message: str
    """

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'status': {'key': 'status', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
    }

    def __init__(self, meter_id=None, status=None, message=None):
        super(BaselineLogEntry, self).__init__()
        self.meter_id = meter_id
        self.status = status
        self.message = message
