# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaselineLog(Model):
    """BaselineLog.

    :param status: The status of baseline processing
    :type status: str
    :param success_count: Number of meters successfully processed
    :type success_count: int
    :param warning_count: Number of meters processed with warnings
    :type warning_count: int
    :param error_count: Number of meters processed with errors
    :type error_count: int
    :param number_of_meters: Number of meters to process
    :type number_of_meters: int
    :param baseline_log_entries: Log entries for the baseline processor
     There will be one per meter processed
    :type baseline_log_entries: list[~energycap.sdk.models.BaselineLogEntry]
    """

    _attribute_map = {
        'status': {'key': 'status', 'type': 'str'},
        'success_count': {'key': 'successCount', 'type': 'int'},
        'warning_count': {'key': 'warningCount', 'type': 'int'},
        'error_count': {'key': 'errorCount', 'type': 'int'},
        'number_of_meters': {'key': 'numberOfMeters', 'type': 'int'},
        'baseline_log_entries': {'key': 'baselineLogEntries', 'type': '[BaselineLogEntry]'},
    }

    def __init__(self, status=None, success_count=None, warning_count=None, error_count=None, number_of_meters=None, baseline_log_entries=None):
        super(BaselineLog, self).__init__()
        self.status = status
        self.success_count = success_count
        self.warning_count = warning_count
        self.error_count = error_count
        self.number_of_meters = number_of_meters
        self.baseline_log_entries = baseline_log_entries
