# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SavingsLogEntry(Model):
    """NOTE: This child object is subject to change depending on what we want to
    log.

    :param meter_id: ID of the meter
    :type meter_id: int
    :param bill_id: ID of the bill
    :type bill_id: int
    :param weather_station_code: Weather station code of the station assigned
     to the meter's parent building
    :type weather_station_code: str
    :param weather_error: Indicates if there was a cost avoidance processing
     problem related to weather
    :type weather_error: bool
    :param auc_error: Indicates if there was a cost avoidance processing
     problem related to average unit cost range configured for this meter's
     commodity
    :type auc_error: bool
    """

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'bill_id': {'key': 'billId', 'type': 'int'},
        'weather_station_code': {'key': 'weatherStationCode', 'type': 'str'},
        'weather_error': {'key': 'weatherError', 'type': 'bool'},
        'auc_error': {'key': 'aucError', 'type': 'bool'},
    }

    def __init__(self, meter_id=None, bill_id=None, weather_station_code=None, weather_error=None, auc_error=None):
        super(SavingsLogEntry, self).__init__()
        self.meter_id = meter_id
        self.bill_id = bill_id
        self.weather_station_code = weather_station_code
        self.weather_error = weather_error
        self.auc_error = auc_error
